#
# HEY! This file has no code, look in bin/cloc instead
#
package App::cloc;

our $VERSION = '1.67';

1;

=head1 NAME

App::cloc - Count Lines of Code

=head1 DESCRIPTION

CPAN packaging of the famous L<CLOC|http://cloc.sourceforge.net/> utility, as agreed with its author Al Danial.

=head1 CREATION

In just downloaded latest code and pod from L<cloc repo|https://github.com/AlDanial/cloc>

    wget https://raw.githubusercontent.com/AlDanial/cloc/master/Unix/cloc -O bin/cloc
    wget https://raw.githubusercontent.com/AlDanial/cloc/master/Unix/cloc.1.pod -O - >> bin/cloc

All credits go to Al Danial.

=head1 LICENSE

Refer to L<CLOC License|https://github.com/AlDanial/cloc/blob/master/LICENSE>

=cut

